<?php
session_start();
if (empty($_SESSION['uid'])) { header('Location: login.php'); exit; }

require_once __DIR__.'/db.php';
require_once __DIR__.'/flash.php';

$uid  = (int)$_SESSION['uid'];
$name = htmlspecialchars($_SESSION['user']);

/* ── stats table (if sender hasn’t created it yet) ───────── */
db()->exec("CREATE TABLE IF NOT EXISTS email_stats(
  user_id INTEGER, day DATE,
  sent INTEGER DEFAULT 0, opened INTEGER DEFAULT 0,
  bounced INTEGER DEFAULT 0, failed INTEGER DEFAULT 0,
  PRIMARY KEY(user_id,day))");

/* ── totals & quota ─────────────────────────────────────── */
$quota = db()->prepare("SELECT plan_quota FROM users WHERE id=?");
$quota->execute([$uid]); $quota = (int)$quota->fetchColumn();

$tot = db()->prepare("
  SELECT COALESCE(SUM(sent),0)     sent ,
         COALESCE(SUM(opened),0)   opened ,
         COALESCE(SUM(bounced),0)  bounced,
         COALESCE(SUM(failed),0)   failed
  FROM email_stats WHERE user_id=?");
$tot->execute([$uid]); $tot = $tot->fetch(PDO::FETCH_ASSOC);

/* last 7-day sparkline */
$days = db()->prepare("
  SELECT day,sent FROM email_stats
  WHERE user_id=? AND day>=date('now','-6 days')
  ORDER BY day");
$days->execute([$uid]); $chart = $days->fetchAll(PDO::FETCH_KEY_PAIR);
for($i=6;$i>=0;$i--){$d=date('Y-m-d',strtotime("-$i days"));if(!isset($chart[$d]))$chart[$d]=0;}
?>
<!doctype html><html lang="en"><head>
<meta charset="utf-8"><title>Dashboard – Mailer Nebula</title>
<meta name="viewport" content="width=device-width,initial-scale=1">
<link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/css/bootstrap.min.css" rel="stylesheet">
<link href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.11.3/font/bootstrap-icons.css" rel="stylesheet">
<script src="https://cdn.jsdelivr.net/npm/chart.js@4.4.0/dist/chart.umd.min.js"></script>
<style>
/* cosmic backdrop */
body{margin:0;min-height:100vh;display:flex;background:#000;color:#fff;
     font-family:system-ui,Segoe UI,Roboto,sans-serif}
body::before{
  content:'';position:fixed;inset:0;z-index:-3;
  background:radial-gradient(circle at 25% 35%,#00ffff33 0 40%,transparent 70%),
             radial-gradient(circle at 80% 75%,#ff00ff33 0 40%,transparent 70%);
}
body::after{
  content:'';position:fixed;inset:0;z-index:-2;
  background:url('https://raw.githubusercontent.com/JulianLaval/canvas-particle-network/master/img/stars.png');
  animation:drift 100s linear infinite}
@keyframes drift{to{transform:translateY(1200px)}}

/* glass sidebar */
.sidebar{width:230px;background:rgba(22,27,34,.75);backdrop-filter:blur(15px);
         border-right:1px solid rgba(255,255,255,.08)}
.sidebar a{color:#adb5bd;text-decoration:none;padding:.65rem 1rem;display:block;transition:.3s}
.sidebar a:hover,.sidebar a.active{background:#0d6efd;color:#fff}
.sidebar .brand{font-weight:600;font-size:1.2rem}
.sidebar .bottom{border-top:1px solid rgba(255,255,255,.1)}

/* glass cards */
.card-glass{
  background:rgba(255,255,255,.05);
  border:1px solid rgba(255,255,255,.12);
  backdrop-filter:blur(12px);
  border-radius:1rem
}
.metric-card{border:none}

/* chart tweaks */
.chart-bg{background:rgba(255,255,255,.03)}
</style>
</head><body>

<!-- ░▒▓  SIDEBAR  ▓▒░ -->
<div class="sidebar d-flex flex-column position-sticky top-0 vh-100">
  <div class="p-3 brand border-bottom border-secondary">Mailer</div>
  <a href="dashboard.php" class="active"><i class="bi bi-speedometer2 me-2"></i>Dashboard</a>
  <a href="smtp.php"><i class="bi bi-hdd-network me-2"></i>SMTP Manager</a>
  <a href="templates.php"><i class="bi bi-file-code me-2"></i>Templates</a>
  <a href="compose.php"><i class="bi bi-send me-2"></i>Compose &amp; Send</a>
  <a href="wallet.php"><i class="bi bi-wallet2 me-2"></i>Wallet</a>
  <a href="plans.php"><i class="bi bi-stars me-2"></i>Plans</a>
  <a href="profile.php"><i class="bi bi-person me-2"></i>Profile</a>
  <?php if ($_SESSION['plan']==='admin'): ?>
    <a href="admin.php"><i class="bi bi-shield-lock me-2"></i>Admin</a>
  <?php endif;?>
  <div class="mt-auto p-3 bottom small">
    Hi, <?=$name?><br>
    <a class="link-warning" href="logout.php">Logout</a>
  </div>
</div>

<!-- ░▒▓  MAIN  ▓▒░ -->
<div class="flex-grow-1 p-4">
  <?php flash_render(); ?>

  <h1 class="h4 mb-4">Overview</h1>

  <!-- metrics -->
  <div class="row g-3">
    <div class="col-6 col-lg-3">
      <div class="card-glass text-center p-3 text-info">
        <div class="fs-4"><?=$quota<0?'∞':number_format($quota)?></div>
        <div class="small text-white-50">Monthly&nbsp;quota</div>
      </div>
    </div>
    <div class="col-6 col-lg-3">
      <div class="card-glass text-center p-3 text-success">
        <div class="fs-4"><?=number_format($tot['sent'])?></div>
        <div class="small text-white-50">Total&nbsp;sent</div>
      </div>
    </div>
    <div class="col-6 col-lg-3">
      <div class="card-glass text-center p-3 text-primary">
        <div class="fs-4"><?=number_format($tot['opened'])?></div>
        <div class="small text-white-50">Total&nbsp;opened</div>
      </div>
    </div>
    <div class="col-6 col-lg-3">
      <div class="card-glass text-center p-3 text-danger">
        <div class="fs-4"><?=number_format($tot['bounced']+$tot['failed'])?></div>
        <div class="small text-white-50">Bounced&nbsp;/&nbsp;failed</div>
      </div>
    </div>
  </div>

  <!-- seven-day chart -->
  <div class="card-glass chart-bg mt-4 p-3">
    <h5 class="card-title mb-3">Last 7&nbsp;days – e-mails sent</h5>
    <canvas id="chart" height="110"></canvas>
  </div>
</div>

<!-- ░▒▓  CHART.JS  ▓▒░ -->
<script>
new Chart(document.getElementById('chart'),{
  type:'line',
  data:{
    labels:<?=json_encode(array_keys($chart))?>,
    datasets:[{data:<?=json_encode(array_values($chart))?>,
      borderColor:'#0ff',borderWidth:2,tension:.3,pointRadius:0,fill:false}]
  },
  options:{
    plugins:{legend:{display:false}},
    scales:{
      x:{ticks:{color:'#fff'},grid:{display:false}},
      y:{ticks:{color:'#fff'},grid:{color:'rgba(255,255,255,.05)'}}
    }
  }
});
</script>
</body></html>
