<?php
// ipn.php — NOWPayments instant-payment notification handler

require_once __DIR__ . '/config.php';
require_once __DIR__ . '/db.php';

/* verify HMAC */
$raw = file_get_contents('php://input');
$sig = $_SERVER['HTTP_X_NOWPAYMENTS_SIG'] ?? '';
if (!$sig || !hash_equals(hash_hmac('sha512',$raw,NOWPAY_API_KEY), $sig)) {
  http_response_code(401); exit('bad signature');
}

$payload = json_decode($raw,true);
if (!$payload || empty($payload['payment_id'])) { http_response_code(400); exit('bad payload'); }

$pid    = $payload['payment_id'];
$status = strtolower($payload['payment_status'] ?? '');

$tx=db()->prepare("SELECT * FROM wallet_tx WHERE payment_id=?");
$tx->execute([$pid]);
$row=$tx->fetch(PDO::FETCH_ASSOC);
if(!$row){ http_response_code(404); exit('not tracked'); }

if(in_array($status,['confirmed','failed'])){
  db()->prepare("UPDATE wallet_tx SET status=? WHERE id=?")
     ->execute([$status,$row['id']]);
  if($status==='confirmed'){
    /* send credit notice */
    $user=db()->prepare("SELECT email FROM users WHERE id=?");
    $user->execute([$row['user_id']]);
    if($mail=$user->fetchColumn()){
      @mail($mail,"Wallet credited \${$row['amount_usd']}",
            "Your wallet has been credited with \${$row['amount_usd']}.\n",
            "From: ".SITE_MAIL_FROM);
    }
  }
}

echo 'OK';
