<?php
/* plans.php – choose / upgrade plan (wallet-aware, futuristic UI) */
session_start();
if (empty($_SESSION['uid'])) { header('Location: login.php'); exit; }

require_once __DIR__.'/db.php';
require_once __DIR__.'/flash.php';

$uid = (int)$_SESSION['uid'];

/* ── add plan columns on first run (safe idempotent) ─────── */
$cols = db()->query("PRAGMA table_info(users)")->fetchAll(PDO::FETCH_COLUMN,1);
if (!in_array('plan',       $cols)) db()->exec("ALTER TABLE users ADD COLUMN plan TEXT DEFAULT 'free'");
if (!in_array('plan_quota', $cols)) db()->exec("ALTER TABLE users ADD COLUMN plan_quota INT  DEFAULT 500");
if (!in_array('plan_expiry',$cols)) db()->exec("ALTER TABLE users ADD COLUMN plan_expiry DATE");

/* ── catalogue ────────────────────────────────────────────── */
$plans = [
  'free'=> ['name'=>'Free','price'=>0,'quota'=>500,'period'=>'month'],
  'p25' => ['name'=>'15 000 / mo','price'=>25,'quota'=>15000,'period'=>'month'],
  'p50' => ['name'=>'50 000 / mo','price'=>50,'quota'=>50000,'period'=>'month'],
  'p100'=> ['name'=>'150 000 / mo','price'=>100,'quota'=>150000,'period'=>'month'],
  'life'=> ['name'=>'Lifetime','price'=>200,'quota'=>-1,'period'=>'lifetime']
];

/* ── buy / upgrade ───────────────────────────────────────── */
if ($_SERVER['REQUEST_METHOD']==='POST' && isset($_POST['plan'])) {
  $code = $_POST['plan'];
  if (!isset($plans[$code])) { flash('error','Unknown plan.'); header('Location: plans.php'); exit; }
  $plan = $plans[$code];

  $bal = db()->query("SELECT COALESCE(SUM(CASE WHEN status IN ('confirmed','spent') THEN amount_usd ELSE 0 END),0)
                      FROM wallet_tx WHERE user_id=$uid")->fetchColumn();

  if ($bal < $plan['price']) {
    flash('error','Balance $'.number_format($bal,2).' – please top-up first.'); header('Location: wallet.php'); exit;
  }

  /* deduct & activate */
  db()->prepare("INSERT INTO wallet_tx (user_id,amount_usd,crypto,status)
                 VALUES (?,?,?,'spent')")->execute([$uid,-$plan['price'],'USD']);

  $expiry = $plan['period']==='month' ? date('Y-m-d',strtotime('+30 days')) : null;
  db()->prepare("UPDATE users SET plan=?,plan_quota=?,plan_expiry=? WHERE id=?")
     ->execute([$code,$plan['quota'],$expiry,$uid]);

  flash('success','Plan activated – enjoy!');
  header('Location: plans.php'); exit;
}

/* ── current user plan info ──────────────────────────────── */
$u = db()->prepare("SELECT plan,plan_quota,plan_expiry FROM users WHERE id=?");
$u->execute([$uid]); $u=$u->fetch(PDO::FETCH_ASSOC);
function dollars($x){return $x==0?'FREE':'$'.number_format($x,2);}
function quota ($q){return $q<0?'Unlimited':number_format($q).' / mo';}
?>
<!doctype html><html lang="en"><head>
<meta charset="utf-8"><title>Plans – Mailer Nebula</title>
<meta name="viewport" content="width=device-width,initial-scale=1">
<link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/css/bootstrap.min.css" rel="stylesheet">
<link href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.11.3/font/bootstrap-icons.css" rel="stylesheet">
<style>
/* cosmic */
body{margin:0;min-height:100vh;display:flex;flex-direction:column;background:#000;color:#fff;font-family:system-ui,Segoe UI,Roboto,sans-serif}
body::before{
  content:'';position:fixed;inset:0;z-index:-3;
  background:radial-gradient(circle at 25% 35%,#00ffff33 0 40%,transparent 70%),
             radial-gradient(circle at 80% 70%,#ff00ff33 0 40%,transparent 70%);
}
body::after{
  content:'';position:fixed;inset:0;z-index:-2;
  background:url('https://raw.githubusercontent.com/JulianLaval/canvas-particle-network/master/img/stars.png');
  animation:drift 120s linear infinite}
@keyframes drift{to{transform:translateY(1400px)}}

/* glass nav */
.navbar{background:rgba(0,0,0,.7)!important;backdrop-filter:blur(12px)}

/* plan cards */
.plan-card{
  background:rgba(255,255,255,.05);
  border:1px solid rgba(255,255,255,.12);
  backdrop-filter:blur(12px);border-radius:1rem;transition:transform .3s;
  box-shadow:0 0 10px rgba(0,255,255,.12);
}
.plan-card:hover{transform:translateY(-6px)}
.plan-card.active{border-color:#0ff;box-shadow:0 0 15px #0ff}

/* neon button */
.btn-neon{position:relative;color:#0ff;font-weight:600;border:1px solid #0ff;text-shadow:0 0 6px #0ff;background:transparent}
.btn-neon::after{content:'';position:absolute;inset:0;border-radius:.35rem;box-shadow:0 0 12px #0ff;opacity:0;transition:.3s}
.btn-neon:hover::after{opacity:1}
</style>
</head><body>

<nav class="navbar navbar-dark">
  <div class="container-fluid">
    <a class="navbar-brand fw-bold" href="dashboard.php">&larr; Dashboard</a>
    <a class="btn btn-outline-light btn-sm" href="logout.php">Logout</a>
  </div>
</nav>

<main class="container py-5 flex-grow-1">

  <?php flash_render(); ?>

  <h1 class="h4 mb-5">Current plan:
    <span class="text-info"><?=strtoupper($u['plan'])?></span>
    <?php if($u['plan_expiry']):?>
      <small class="text-white-50">(renews&nbsp;<?=htmlspecialchars($u['plan_expiry'])?>)</small>
    <?php endif;?>
  </h1>

  <div class="row g-4 justify-content-center">
  <?php foreach($plans as $code=>$p):?>
    <div class="col-12 col-md-6 col-lg-4">
      <div class="plan-card h-100 text-center p-4 <?=$code==$u['plan']?'active':''?>">
        <h3 class="h5 mb-3"><?=$p['name']?></h3>

        <p class="display-6 fw-bold mb-1"><?=dollars($p['price'])?></p>
        <p class="small text-info mb-4"><?=quota($p['quota'])?></p>

        <?php if($code==$u['plan']):?>
          <button class="btn btn-success w-100" disabled>Current plan</button>
        <?php else:?>
          <form method="post">
            <input type="hidden" name="plan" value="<?=$code?>">
            <button class="btn btn-neon w-100">Activate</button>
          </form>
        <?php endif;?>
      </div>
    </div>
  <?php endforeach;?>
  </div>
</main>

<footer class="text-center text-white-50 py-3 small">&copy; <?=date('Y')?> Mailer Nebula</footer>
</body></html>
