<?php
/* profile.php – edit account details (dark bootstrap) */

session_start();
if (empty($_SESSION['uid'])) { header('Location: login.php'); exit; }

require_once __DIR__.'/db.php';
require_once __DIR__.'/flash.php';

$uid = (int)$_SESSION['uid'];

/* ── handle “update info” ─────────────────────────────────── */
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['action'])) {
    $act = $_POST['action'];

    /* Update name + e-mail */
    if ($act === 'info') {
        $name  = trim($_POST['username'] ?? '');
        $email = trim($_POST['email'] ?? '');

        if ($name === '' || $email === '') {
            flash('error', 'Name and e-mail are required.');
            header('Location: profile.php'); exit;
        }
        if (!filter_var($email, FILTER_VALIDATE_EMAIL)) {
            flash('error','Invalid e-mail address.'); header('Location: profile.php'); exit;
        }

        /* e-mail already used by someone else? */
        $check = db()->prepare("SELECT id FROM users WHERE email=? AND id<>?");
        $check->execute([$email, $uid]);
        if ($check->fetch()) {
            flash('error','This e-mail is already registered.'); header('Location: profile.php'); exit;
        }

        db()->prepare("UPDATE users SET username=?, email=? WHERE id=?")
           ->execute([$name, $email, $uid]);

        /* refresh session values */
        $_SESSION['user'] = $name;

        flash('success','Profile updated.');
        header('Location: profile.php'); exit;
    }

    /* Change password */
    if ($act === 'pwd') {
        $cur = $_POST['cur'] ?? '';
        $n1  = $_POST['new1'] ?? '';
        $n2  = $_POST['new2'] ?? '';

        if ($n1 === '' || $n2 === '') {
            flash('error','New password cannot be empty.'); header('Location: profile.php'); exit;
        }
        if ($n1 !== $n2) {
            flash('error','Passwords do not match.'); header('Location: profile.php'); exit;
        }
        if (strlen($n1) < 6) {
            flash('error','Password must be at least 6 characters.'); header('Location: profile.php'); exit;
        }

        $row = db()->prepare("SELECT password_hash FROM users WHERE id=?");
        $row->execute([$uid]); $hash = $row->fetchColumn();

        if (!password_verify($cur, $hash)) {
            flash('error','Current password is incorrect.'); header('Location: profile.php'); exit;
        }

        $newHash = password_hash($n1, PASSWORD_DEFAULT);
        db()->prepare("UPDATE users SET password_hash=? WHERE id=?")
           ->execute([$newHash, $uid]);

        flash('success','Password changed.');
        header('Location: profile.php'); exit;
    }
}

/* ── fetch current data for form ─────────────────────────── */
$user = db()->prepare("SELECT username,email FROM users WHERE id=?");
$user->execute([$uid]); $user = $user->fetch(PDO::FETCH_ASSOC);
?>
<!doctype html><html lang="en"><head>
<meta charset="utf-8"><title>Profile</title>
<link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/css/bootstrap.min.css" rel="stylesheet">
<style>
body  {background:#0d1117;color:#fff}
.card {background:#161b22}
.card-body {color:#fff}      /* ← add this */
</style>
</head><body>

<nav class="navbar navbar-dark bg-dark">
  <div class="container-fluid">
    <a class="navbar-brand" href="dashboard.php">&larr; Dashboard</a>
    <a class="btn btn-outline-light btn-sm" href="logout.php">Logout</a>
  </div>
</nav>

<div class="container py-5">

  <?php flash_render(); ?>

  <h1 class="h4 mb-4">Account settings</h1>

  <!-- profile info -->
  <div class="row gy-4">
    <div class="col-md-6">
      <div class="card">
        <div class="card-body">
          <h5 class="card-title mb-3">Profile information</h5>
          <form method="post">
            <input type="hidden" name="action" value="info">
            <div class="mb-3">
              <label class="form-label">Name</label>
              <input name="username" class="form-control" value="<?=htmlspecialchars($user['username'])?>" required>
            </div>
            <div class="mb-3">
              <label class="form-label">E-mail</label>
              <input name="email" type="email" class="form-control" value="<?=htmlspecialchars($user['email'])?>" required>
            </div>
            <button class="btn btn-primary">Save changes</button>
          </form>
        </div>
      </div>
    </div>

    <!-- password -->
    <div class="col-md-6">
      <div class="card">
        <div class="card-body">
          <h5 class="card-title mb-3">Change password</h5>
          <form method="post">
            <input type="hidden" name="action" value="pwd">
            <div class="mb-3">
              <label class="form-label">Current password</label>
              <input name="cur" type="password" class="form-control" required>
            </div>
            <div class="mb-3">
              <label class="form-label">New password</label>
              <input name="new1" type="password" class="form-control" required>
            </div>
            <div class="mb-3">
              <label class="form-label">Repeat new password</label>
              <input name="new2" type="password" class="form-control" required>
            </div>
            <button class="btn btn-warning">Change password</button>
          </form>
        </div>
      </div>
    </div>
  </div>
</div>
</body></html>
