<?php
/* smtp.php — SMTP Manager with bulk select/delete/test */
session_start();
if (empty($_SESSION['uid'])) { header('Location: login.php'); exit; }
require_once __DIR__ . '/db.php';
$uid = (int)$_SESSION['uid'];

/* ── DB bootstrap ───────────────────────────────────────── */
db()->exec("
CREATE TABLE IF NOT EXISTS smtp_servers (
  id INTEGER PRIMARY KEY AUTOINCREMENT,
  user_id INTEGER,
  host TEXT, port INTEGER,
  username TEXT, password TEXT,
  from_email TEXT,
  last_health TEXT DEFAULT 'unknown',
  sent_count INTEGER DEFAULT 0,
  fail_count INTEGER DEFAULT 0
);
CREATE TABLE IF NOT EXISTS smtp_test_emails (
  user_id INTEGER PRIMARY KEY,
  emails  TEXT
);
");

/* ── JSON API ─────────────────────────────────────────── */
if ($_SERVER['REQUEST_METHOD']==='POST' && isset($_POST['action'])) {
  header('Content-Type: application/json'); $a=$_POST['action'];

  /* SAVE row ----------------------------------------------------------- */
  if ($a==='save') {
    $d=[trim($_POST['host']),(int)$_POST['port'],
        trim($_POST['username']),trim($_POST['password']),
        trim($_POST['from'])];
    if (empty($_POST['id'])) {
      db()->prepare("INSERT INTO smtp_servers
        (user_id,host,port,username,password,from_email)
        VALUES (?,?,?,?,?,?)")->execute(array_merge([$uid],$d));
    } else {
      db()->prepare("UPDATE smtp_servers SET host=?,port=?,username=?,password=?,from_email=?
                     WHERE id=? AND user_id=?")
         ->execute(array_merge($d,[(int)$_POST['id'],$uid]));
    }
    echo json_encode(['ok'=>1]); exit;
  }

  /* DELETE single ------------------------------------------------------ */
  if ($a==='delete') {
    db()->prepare("DELETE FROM smtp_servers WHERE id=? AND user_id=?")
       ->execute([(int)$_POST['id'],$uid]);
    echo json_encode(['ok'=>1]); exit;
  }

  /* DELETE BULK -------------------------------------------------------- */
  if ($a==='delete_bulk') {
    $ids = array_filter(array_map('intval', explode(',', $_POST['ids']??'')));
    if (!$ids) { echo json_encode(['err'=>'no ids']); exit; }
    $in  = implode(',', array_fill(0,count($ids),'?'));
    $stmt=db()->prepare("DELETE FROM smtp_servers WHERE user_id=? AND id IN ($in)");
    $stmt->execute(array_merge([$uid],$ids));
    echo json_encode(['ok'=>1,'deleted'=>count($ids)]); exit;
  }

  /* LIST --------------------------------------------------------------- */
  if ($a==='list') {
    $rows=db()->prepare("SELECT * FROM smtp_servers WHERE user_id=? ORDER BY id DESC");
    $rows->execute([$uid]);
    echo json_encode($rows->fetchAll(PDO::FETCH_ASSOC)); exit;
  }

  /* BULK upload -------------------------------------------------------- */
  if ($a==='bulk' && !empty($_FILES['file']['tmp_name'])) {
    $lines=array_filter(array_map('trim',file($_FILES['file']['tmp_name'])));
    $added=$skip=0;
    $ins=db()->prepare("INSERT INTO smtp_servers
      (user_id,host,port,username,password,from_email)
      VALUES (?,?,?,?,?,?)");
    foreach($lines as $ln){
      $p=explode('|',$ln,5);
      if(count($p)!=5){$skip++;continue;}
      try{$ins->execute([$uid,$p[0],(int)$p[1],$p[2],$p[3],$p[4]]);$added++;}
      catch(PDOException $e){$skip++;}
    }
    echo json_encode(['added'=>$added,'skipped'=>$skip]); exit;
  }

  /* GET / SAVE test addresses ----------------------------------------- */
  if ($a==='get_tests') {
    $row=db()->prepare("SELECT emails FROM smtp_test_emails WHERE user_id=?");
    $row->execute([$uid]);
    echo json_encode(['emails'=>$row->fetchColumn()?:'']); exit;
  }
  if ($a==='save_tests') {
    db()->prepare("INSERT INTO smtp_test_emails (user_id,emails)
                   VALUES (?,?) ON CONFLICT(user_id) DO UPDATE
                   SET emails=excluded.emails")
       ->execute([$uid,substr($_POST['emails']??'',0,1000)]);
    echo json_encode(['ok'=>1]); exit;
  }

  /* TEST ONE ----------------------------------------------------------- */
  if ($a==='test_one') {
    $id=(int)$_POST['id']; $to=trim($_POST['to']);
    $row=db()->prepare("SELECT * FROM smtp_servers WHERE id=? AND user_id=?");
    $row->execute([$id,$uid]); $s=$row->fetch(PDO::FETCH_ASSOC);
    if(!$s){echo json_encode(['err'=>'not found']);exit;}

    $py = escapeshellcmd("python smtptest.py ".
          escapeshellarg($s['host'])." ".$s['port']." ".
          escapeshellarg($s['username'])." ".
          escapeshellarg($s['password'])." ".
          escapeshellarg($s['from_email'])." ".
          escapeshellarg($to));
    exec($py,$out,$ret);
    $ok = ($ret===0);

    db()->prepare("UPDATE smtp_servers SET last_health=? WHERE id=?")
       ->execute([$ok?'good':'bad',$id]);
    if(!$ok) db()->prepare("UPDATE smtp_servers SET fail_count=fail_count+1 WHERE id=?")->execute([$id]);

    echo json_encode(['ok'=>$ok,'host'=>$s['host']]); exit;
  }

  echo json_encode(['err'=>'bad action']); exit;
}
/* ── END API ───────────────────────────────────── */
?>
<!doctype html><html lang="en"><head>
<meta charset="utf-8"><title>SMTP Manager</title>
<link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/css/bootstrap.min.css" rel="stylesheet">
<link href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.11.3/font/bootstrap-icons.css" rel="stylesheet">
<style>
body{background:#0d1117;color:#fff}
.btn-neon{position:relative;color:#0ff;border:1px solid #0ff;text-shadow:0 0 6px #0ff}
.btn-neon::after{content:'';position:absolute;inset:0;box-shadow:0 0 12px #0ff;opacity:0;transition:.3s}
.btn-neon:hover::after{opacity:1}
.drag{background:#19875433 !important}
</style>
</head><body class="d-flex flex-column min-vh-100">

<nav class="navbar navbar-dark bg-dark">
  <div class="container-fluid">
    <a class="navbar-brand" href="dashboard.php">&larr; Dashboard</a>
    <a href="logout.php" class="btn btn-outline-light btn-sm">Logout</a>
  </div>
</nav>

<main class="container py-5 flex-grow-1">
  <h1 class="h4 mb-3">SMTP Manager</h1>

  <!-- Add / edit -->
  <form id="smtpForm" class="row g-2 mb-4">
    <input type="hidden" name="id" id="rowId">
    <div class="col-lg-2"><input name="host" id="host" class="form-control" placeholder="host" required></div>
    <div class="col-lg-1"><input name="port" id="port" class="form-control" placeholder="port" type="number" required></div>
    <div class="col-lg-2"><input name="username" id="user" class="form-control" placeholder="user" required></div>
    <div class="col-lg-2"><input name="password" id="pwd" class="form-control" placeholder="pass" required></div>
    <div class="col-lg-3"><input name="from" id="from" class="form-control" placeholder="from email" required></div>
    <div class="col-lg-2"><button class="btn btn-neon w-100">Save</button></div>
  </form>

  <!-- Bulk upload -->
  <div id="drop" class="p-4 rounded border border-info text-center mb-4" style="cursor:pointer">
    <i class="bi bi-cloud-arrow-up fs-3"></i><br>Drag & drop <code>smtp_bulk.txt</code> here
  </div>

  <!-- Action buttons -->
  <div class="d-flex justify-content-between mb-2">
    <div>
      <button id="btnDeleteSel" class="btn btn-danger btn-sm me-2" disabled>
        <i class="bi bi-trash"></i> Delete&nbsp;selected
      </button>
      <button id="btnTestSel" class="btn btn-neon btn-sm me-2" data-bs-toggle="modal"
              data-bs-target="#testModal" disabled>
        <i class="bi bi-play-circle"></i> Test&nbsp;selected
      </button>
    </div>
    <button class="btn btn-neon btn-sm" data-bs-toggle="modal" data-bs-target="#testModal">
      <i class="bi bi-play-circle me-1"></i> Test&nbsp;all&nbsp;SMTPs
    </button>
  </div>

  <!-- table -->
  <div class="table-responsive">
    <table class="table table-dark table-sm text-center align-middle" id="tbl">
      <thead>
        <tr>
          <th><input type="checkbox" id="selAll"></th>
          <th>Server</th><th>User</th><th>From</th><th>Health</th><th></th>
        </tr>
      </thead>
      <tbody></tbody>
    </table>
  </div>
</main>

<!-- Test modal -->
<div class="modal fade" id="testModal" tabindex="-1"><div class="modal-dialog modal-lg">
<div class="modal-content bg-dark text-white">
  <div class="modal-header">
    <h5 class="modal-title">SMTP Testing</h5>
    <button class="btn-close btn-close-white" data-bs-dismiss="modal"></button>
  </div>
  <div class="modal-body">
    <textarea id="testEmails" class="form-control mb-3" rows="5"
              placeholder="Up to 10 emails (one per line)"></textarea>
    <pre id="result" class="small text-white-50" style="min-height:150px"></pre>
  </div>
  <div class="modal-footer">
    <button class="btn btn-outline-info" id="saveTests">Save addresses</button>
    <button class="btn btn-neon" id="runTests">Run&nbsp;Test</button>
  </div>
</div></div></div>

<footer class="text-center text-white-50 py-3 small">&copy; <?=date('Y')?> Mailer Nebula</footer>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/js/bootstrap.bundle.min.js"></script>
<script>
const api=fd=>fetch('smtp.php',{method:'POST',body:fd}).then(r=>r.json());

/* toast helper */
function toast(m,t='info'){const d=document.createElement('div');
d.className=`alert alert-${t} position-fixed top-0 end-0 m-3 py-2 px-3 fade`;
d.style.zIndex=1080; d.textContent=m; document.body.append(d);
new bootstrap.Alert(d); setTimeout(()=>d.classList.add('show'),10);
setTimeout(()=>d.classList.remove('show'),3000);}

/* load table */
function load(){
  const fd=new FormData(); fd.append('action','list');
  api(fd).then(rows=>{
    const tb=document.querySelector('#tbl tbody'); tb.innerHTML='';
    rows.forEach(r=>{
      tb.insertAdjacentHTML('beforeend',`
<tr data-id="${r.id}">
  <td><input type="checkbox" class="sel"></td>
  <td>${r.host}:${r.port}</td>
  <td>${r.username}</td>
  <td>${r.from_email}</td>
  <td><span class="badge bg-${col(r.last_health)}">${r.last_health}</span></td>
  <td>
    <button class="btn btn-sm btn-outline-warning me-1" onclick="editRow(${r.id})">
      <i class="bi bi-pencil"></i>
    </button>
    <button class="btn btn-sm btn-outline-danger" onclick="delRow(${r.id})">
      <i class="bi bi-trash"></i>
    </button>
  </td>
</tr>`);});
    updateSelButtons();
  });
}
const col=h=>({good:'success',bad:'danger',unknown:'secondary'})[h]||'secondary';

/* selection helpers */
function selectedIds(){
  return [...document.querySelectorAll('.sel:checked')].map(c=>c.closest('tr').dataset.id);
}
function updateSelButtons(){
  const any=selectedIds().length>0;
  btnDeleteSel.disabled=!any;
  btnTestSel  .disabled=!any;
}
document.addEventListener('change',e=>{
  if(e.target.id==='selAll'){
    document.querySelectorAll('.sel').forEach(c=>c.checked=e.target.checked);
  }
  if(e.target.classList.contains('sel')) updateSelButtons();
});

/* save / edit */
smtpForm.addEventListener('submit',e=>{
  e.preventDefault();
  const fd=new FormData(e.target); fd.append('action','save');
  api(fd).then(()=>{e.target.reset();toast('Saved','success');load();});
});
function editRow(id){
  const tr=document.querySelector(`tr[data-id="${id}"]`);
  if(!tr)return;
  const td=tr.querySelectorAll('td');
  rowId.value=id;
  host.value = td[1].textContent.split(':')[0];
  port.value = td[1].textContent.split(':')[1];
  user.value = td[2].textContent;
  from.value = td[3].textContent;
}

/* delete single / bulk */
function delRow(id){
  if(!confirm('Delete this SMTP?'))return;
  const fd=new FormData(); fd.append('action','delete'); fd.append('id',id);
  api(fd).then(()=>{toast('Deleted','warning');load();});
}
btnDeleteSel.onclick=()=>{
  const ids=selectedIds(); if(!ids.length)return;
  if(!confirm(`Delete ${ids.length} SMTP(s)?`))return;
  const fd=new FormData(); fd.append('action','delete_bulk'); fd.append('ids',ids.join(','));
  api(fd).then(()=>{toast('Deleted','warning');load();});
};

/* drag-drop bulk */
['dragover','dragenter'].forEach(ev=>drop.addEventListener(ev,e=>{e.preventDefault();drop.classList.add('drag');}));
['dragleave','drop'].forEach(ev=>drop.addEventListener(ev,()=>drop.classList.remove('drag')));
drop.addEventListener('drop',e=>{
  e.preventDefault(); const f=e.dataTransfer.files[0]; if(!f)return;
  const fd=new FormData(); fd.append('action','bulk'); fd.append('file',f);
  api(fd).then(r=>{toast(`Added ${r.added}, skipped ${r.skipped}`,'info');load();});
});

/* modal */
testModal.addEventListener('show.bs.modal',()=>{
  const fd=new FormData(); fd.append('action','get_tests');
  api(fd).then(r=>testEmails.value=r.emails);
});
saveTests.onclick=()=>{
  const fd=new FormData(); fd.append('action','save_tests'); fd.append('emails',testEmails.value);
  api(fd).then(()=>toast('Saved','success'));
};
/* ── Run tests (selected or all) ───────────────────────── */
runTests.onclick = async () => {
  result.textContent = '';

  /* which rows to test? */
  const ids = selectedIds().length
           ? selectedIds()
           : [...document.querySelectorAll('#tbl tbody tr')].map(tr => tr.dataset.id);

  if (!ids.length) { result.textContent = 'Nothing to test.'; return; }

  /* collect recipients */
  const recips = testEmails.value
                   .trim()
                   .split(/\n+/)
                   .map(e => e.trim())
                   .filter(Boolean);
  if (!recips.length) { toast('Add at least one test address','warning'); return; }

  const toCSV = recips.join(',');

  /* loop rows */
  for (const id of ids) {
    const tr   = document.querySelector(`tr[data-id="${id}"]`);
    const host = tr.children[1].textContent;

    result.textContent += `Testing ${host} … `;
    const fd = new FormData();
    fd.append('action', 'test_one');
    fd.append('id',  id);
    fd.append('to',  toCSV);

    const r = await api(fd);
    if (r.ok) {
      result.textContent += 'OK\n';
      tr.querySelector('span.badge').className = 'badge bg-success';
    } else {
      result.textContent += 'FAIL\n';
      tr.querySelector('span.badge').className = 'badge bg-danger';
    }
  }
  toast('Testing complete', 'info');
};

/* init */
load();
</script>
</body></html>
