#!/usr/bin/env python3
"""
telegram_send.py TOKEN CHAT_ID MESSAGE

Prints 'OK' on success.
Prints Telegram or network error text on failure.
Exit-code: 0 = sent, 1 = error
"""

import sys, json, urllib.parse, urllib.request, ssl

if len(sys.argv) < 4:
    print("usage: telegram_send.py <token> <chat_id> <message>", file=sys.stderr)
    sys.exit(1)

token, chat_id, message = sys.argv[1], sys.argv[2], " ".join(sys.argv[3:])
url  = f"https://api.telegram.org/bot{token}/sendMessage"
data = urllib.parse.urlencode({"chat_id": chat_id, "text": message}).encode()

ctx  = ssl.create_default_context()
ctx.check_hostname = False
ctx.verify_mode    = ssl.CERT_NONE        # works even without cert bundle

try:
    resp = urllib.request.urlopen(url, data=data, timeout=15, context=ctx)
    js   = json.loads(resp.read().decode())
    if js.get("ok"):
        print("OK")
        sys.exit(0)
    print(js.get("description", "telegram error"), file=sys.stderr)
except Exception as e:
    print(str(e), file=sys.stderr)

sys.exit(1)
