<?php
/* templates.php — Template Manager v2 (futuristic UI) */
session_start();
if (empty($_SESSION['uid'])) { header('Location: login.php'); exit; }
require_once __DIR__.'/db.php';
$uid = (int)$_SESSION['uid'];

/* ── DB bootstrap ───────────────────────────────────────── */
db()->exec("CREATE TABLE IF NOT EXISTS email_templates (
  id INTEGER PRIMARY KEY AUTOINCREMENT,
  user_id INTEGER,
  name TEXT,
  html TEXT,
  updated_at DATETIME DEFAULT CURRENT_TIMESTAMP
)");

/* ── JSON API ───────────────────────────────────────────── */
if ($_SERVER['REQUEST_METHOD']==='POST' && isset($_POST['action'])) {
  header('Content-Type: application/json');
  $a = $_POST['action'];

  /* save (add / edit) */
  if ($a==='save') {
    $name = trim($_POST['name']??'');
    $html = $_POST['html'] ?? '';
    if (!$name || !$html) { echo json_encode(['err'=>'empty']); exit; }

    if (empty($_POST['id'])) {
      db()->prepare("INSERT INTO email_templates (user_id,name,html)
                     VALUES (?,?,?)")->execute([$uid,$name,$html]);
    } else {
      db()->prepare("UPDATE email_templates
                     SET name=?,html=?,updated_at=CURRENT_TIMESTAMP
                     WHERE id=? AND user_id=?")
         ->execute([$name,$html,(int)$_POST['id'],$uid]);
    }
    echo json_encode(['ok'=>1]); exit;
  }

  /* fetch one */
  if ($a==='get') {
    $st = db()->prepare("SELECT * FROM email_templates WHERE id=? AND user_id=?");
    $st->execute([(int)$_POST['id'],$uid]);
    echo json_encode($st->fetch(PDO::FETCH_ASSOC)); exit;
  }

  /* list all (id, name, size, date) */
  if ($a==='list') {
    $st = db()->prepare("
      SELECT id,name,updated_at,length(html) bytes
      FROM email_templates WHERE user_id=?
      ORDER BY id DESC");
    $st->execute([$uid]);
    echo json_encode($st->fetchAll(PDO::FETCH_ASSOC)); exit;
  }

  /* delete one */
  if ($a==='delete') {
    db()->prepare("DELETE FROM email_templates WHERE id=? AND user_id=?")
       ->execute([(int)$_POST['id'],$uid]);
    echo json_encode(['ok'=>1]); exit;
  }

  /* delete bulk */
  if ($a==='delete_bulk') {
    $ids = array_filter(array_map('intval', explode(',', $_POST['ids']??'')));
    if (!$ids) { echo json_encode(['err'=>'no ids']); exit; }
    $in = implode(',', array_fill(0,count($ids),'?'));
    db()->prepare("DELETE FROM email_templates
                   WHERE user_id=? AND id IN ($in)")
       ->execute(array_merge([$uid],$ids));
    echo json_encode(['ok'=>1]); exit;
  }

  echo json_encode(['err'=>'bad action']); exit;
}
?>
<!doctype html><html lang="en"><head>
<meta charset="utf-8"><title>Template Manager – Mailer Nebula</title>
<meta name="viewport" content="width=device-width,initial-scale=1">
<link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/css/bootstrap.min.css" rel="stylesheet">
<link href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.11.3/font/bootstrap-icons.css" rel="stylesheet">
<style>
/* cosmic backdrop */
body{background:#0d1117;color:#fff;font-family:system-ui,Segoe UI,Roboto,sans-serif}
body::before{
  content:'';position:fixed;inset:0;z-index:-3;
  background:radial-gradient(circle at 25% 35%,#00ffff33 0 40%,transparent 70%),
             radial-gradient(circle at 80% 70%,#ff00ff33 0 40%,transparent 70%);
}
body::after{
  content:'';position:fixed;inset:0;z-index:-2;
  background:url('https://raw.githubusercontent.com/JulianLaval/canvas-particle-network/master/img/stars.png');
  animation:drift 100s linear infinite}
@keyframes drift{to{transform:translateY(1200px)}}

/* neon buttons */
.btn-neon{position:relative;color:#0ff;border:1px solid #0ff;font-weight:600;text-shadow:0 0 6px #0ff}
.btn-neon::after{content:'';position:absolute;inset:0;border-radius:.35rem;
  box-shadow:0 0 12px #0ff;opacity:0;transition:.3s}
.btn-neon:hover::after{opacity:1}

/* previews */
iframe.mini{height:280px;width:100%;border:1px solid #555;border-radius:.5rem;
            box-shadow:0 0 8px #0ff55a}
.modal-fullscreen .modal-content{background:rgba(0,0,0,.85);border:1px solid #0ff;
  backdrop-filter:blur(20px)}
iframe.full{height:100vh;width:100%;border:0}
</style>
</head><body class="d-flex flex-column min-vh-100">

<nav class="navbar navbar-dark bg-dark">
  <div class="container-fluid">
    <a class="navbar-brand" href="dashboard.php">&larr; Dashboard</a>
    <a href="logout.php" class="btn btn-outline-light btn-sm">Logout</a>
  </div>
</nav>

<main class="container py-5 flex-grow-1">
  <h1 class="h4 mb-4">Template Manager</h1>

  <!-- form -->
  <form id="tplForm" class="row g-3 mb-5">
    <input type="hidden" name="id" id="tplId">
    <div class="col-lg-4"><input name="name" id="tplName" class="form-control" placeholder="Template name" required></div>
    <div class="col-lg-8"><input type="file" id="fileHtml" accept=".html" class="form-control"></div>
    <div class="col-12"><textarea name="html" id="tplHtml" class="form-control" rows="8" placeholder="Paste HTML here" required></textarea></div>
    <div class="col-12"><iframe id="miniPrev" class="mini"></iframe></div>
    <div class="col-12 d-flex gap-2">
      <button class="btn btn-neon px-4">Save</button>
      <button type="button" class="btn btn-secondary" onclick="openModalPreview('unsaved')">
        <i class="bi bi-arrows-fullscreen me-1"></i>Full preview
      </button>
    </div>
  </form>

  <!-- list header + bulk delete -->
  <div class="d-flex justify-content-between align-items-end mb-2">
    <h2 class="h5">Saved templates</h2>
    <button id="btnDelSel" class="btn btn-danger btn-sm" disabled>
      <i class="bi bi-trash"></i> Delete selected
    </button>
  </div>

  <!-- list -->
  <div class="table-responsive">
    <table class="table table-dark table-sm text-center align-middle" id="tbl">
      <thead><tr><th><input type="checkbox" id="selAll"></th>
        <th>Name</th><th>Size</th><th>Updated</th><th></th></tr></thead>
      <tbody></tbody>
    </table>
  </div>
</main>

<!-- full preview modal -->
<div class="modal fade" id="prevModal" tabindex="-1">
  <div class="modal-dialog modal-fullscreen">
    <div class="modal-content">
      <div class="modal-header border-0">
        <h5 class="modal-title" id="prevTitle">Preview</h5>
        <button class="btn-close btn-close-white" data-bs-dismiss="modal"></button>
      </div>
      <div class="modal-body p-0"><iframe id="fullPrev" class="full"></iframe></div>
    </div>
  </div>
</div>

<footer class="text-center text-white-50 py-3 small">&copy; <?=date('Y')?> Mailer Nebula</footer>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/js/bootstrap.bundle.min.js"></script>
<script>
const api=fd=>fetch('templates.php',{method:'POST',body:fd}).then(r=>r.json());

/* toast */
function toast(txt,cls='info'){const d=document.createElement('div');
d.className=`alert alert-${cls} position-fixed top-0 end-0 m-3 py-2 px-3 fade`;d.style.zIndex=1080;
d.textContent=txt;document.body.append(d);new bootstrap.Alert(d);
setTimeout(()=>d.classList.add('show'),10);setTimeout(()=>d.classList.remove('show'),3000);}

/* live mini preview */
function updateMini(){miniPrev.srcdoc=tplHtml.value;}
tplHtml.addEventListener('input',updateMini);
fileHtml.onchange=()=>fileHtml.files[0]?.text().then(t=>{tplHtml.value=t;updateMini();});

/* list loader */
function load(){
  const fd=new FormData();fd.append('action','list');
  api(fd).then(rows=>{
    const tb=document.querySelector('#tbl tbody');tb.innerHTML='';
    rows.forEach(r=>{
      tb.insertAdjacentHTML('beforeend',`
<tr data-id="${r.id}">
 <td><input type="checkbox" class="sel"></td>
 <td>${r.name}</td>
 <td><span class="badge bg-info">${r.bytes}</span></td>
 <td>${r.updated_at.split(' ')[0]}</td>
 <td>
   <button class="btn btn-sm btn-outline-info me-1" onclick="openModalPreview(${r.id})"><i class="bi bi-eye"></i></button>
   <button class="btn btn-sm btn-outline-warning me-1" onclick="editTpl(${r.id})"><i class="bi bi-pencil"></i></button>
   <button class="btn btn-sm btn-outline-danger" onclick="delTpl(${r.id})"><i class="bi bi-trash"></i></button>
 </td>
</tr>`);});
    syncSel();
  });
}

/* selection helpers */
selAll.onchange=()=>document.querySelectorAll('.sel').forEach(c=>c.checked=selAll.checked);
document.addEventListener('change',e=>{if(e.target.classList.contains('sel'))syncSel();});
function selected(){return[...document.querySelectorAll('.sel:checked')].map(c=>c.closest('tr').dataset.id);}
function syncSel(){btnDelSel.disabled=!selected().length;selAll.checked=[...document.querySelectorAll('.sel')].every(c=>c.checked);}

/* save */
tplForm.addEventListener('submit',e=>{
  e.preventDefault();
  const fd=new FormData(e.target);fd.append('action','save');
  api(fd).then(r=>{if(r.ok){toast('Template saved','success');tplForm.reset();miniPrev.srcdoc='';load();}});
});

/* edit */
function editTpl(id){
  const fd=new FormData();fd.append('action','get');fd.append('id',id);
  api(fd).then(r=>{
    tplId.value=r.id;tplName.value=r.name;tplHtml.value=r.html;updateMini();
    window.scrollTo({top:0,behavior:'smooth'});
  });
}

/* delete single / bulk */
function delTpl(id){
  if(!confirm('Delete this template?'))return;
  const fd=new FormData();fd.append('action','delete');fd.append('id',id);
  api(fd).then(()=>{toast('Deleted','warning');load();});
}
btnDelSel.onclick=()=>{
  const ids=selected();if(!ids.length)return;
  if(!confirm(`Delete ${ids.length} template(s)?`))return;
  const fd=new FormData();fd.append('action','delete_bulk');fd.append('ids',ids.join(','));
  api(fd).then(()=>{toast('Deleted','warning');load();});
};

/* modal preview */
function openModalPreview(id){
  if(id==='unsaved'){
    fullPrev.srcdoc=tplHtml.value||'<h3 class="text-danger">No HTML</h3>';
    prevTitle.textContent='Preview (unsaved)';
    new bootstrap.Modal('#prevModal').show();return;
  }
  const tr=document.querySelector(`tr[data-id="${id}"]`);
  prevTitle.textContent='Preview – '+tr.children[1].textContent;
  const fd=new FormData();fd.append('action','get');fd.append('id',id);
  api(fd).then(r=>{fullPrev.srcdoc=r.html;});
  new bootstrap.Modal('#prevModal',{keyboard:true}).show();
}

/* init */
load();updateMini();
</script>
</body></html>
